@@ -96,7 +96,7 @@ bool CommonWidget::buildPortRangesTables( const boolPtr tcpPorts, const boolPtr
 			portRange = portRange.right( portRange.length( ) - 2 );
 		}
 		else
-		{	KMessageBox::error( this, i18n( TQString( "Internal error - Unknown Port Range protocol '%1'" ).arg( portRange[ 0 ])), i18n( "Internal error" ));
+		{	KMessageBox::error( this, i18n( "Internal error - Unknown Port Range protocol '%1'" ).arg( portRange[ 0 ]), i18n( "Internal error" ));
 			return false;
 		}
 
@@ -228,33 +228,33 @@ void CommonWidget::enablePortRangeWidgets( )
 void CommonWidget::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_hostButton,             SIGNAL( clicked( )),                     SLOT( slotHostButtonClicked( )));
-	connect( m_hostComboBox,           SIGNAL( activated( int )),               SLOT( slotHostActivated( int )));
-	connect( m_hostComboBox,           SIGNAL( textChanged( const TQString& )),  SLOT( slotHostTextChanged( const TQString& )));
-	connect( m_portRangeAddButton,     SIGNAL( clicked( )),                     SLOT( slotPortRangeAddClicked( )));
-	connect( m_portRangeButton,        SIGNAL( clicked( )),                     SLOT( slotPortRangeButtonClicked( )));
-	connect( m_portRangeDeleteButton,  SIGNAL( clicked( )),                     SLOT( slotPortRangeDeleteClicked( )));
-	connect( m_portRangeComboBox,      SIGNAL( activated( int )),               SLOT( slotPortRangeActivated( int )));
-	connect( m_portRangeLineEdit,      SIGNAL( textChanged( const TQString& )),  SLOT( slotPortRangeTextChanged( const TQString& )));
-	connect( m_portRangeListBox,       SIGNAL( doubleClicked( TQListBoxItem* )), SLOT( slotPortRangeDoubleClicked( TQListBoxItem* )));
-	connect( m_portRangeListBox,       SIGNAL( highlighted( int )),             SLOT( slotPortRangeHighlighted( )));
-	connect( m_portRangesCheckBox,     SIGNAL( clicked( )),                     SLOT( slotPortRangesClicked( )));
-	connect( whatsThis,                SIGNAL( clicked( )),                     SLOT( slotWhatsThisClicked( )));
+	connect( m_hostButton,             TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotHostButtonClicked( )));
+	connect( m_hostComboBox,           TQ_SIGNAL( activated( int )),               TQ_SLOT( slotHostActivated( int )));
+	connect( m_hostComboBox,           TQ_SIGNAL( textChanged( const TQString& )),  TQ_SLOT( slotHostTextChanged( const TQString& )));
+	connect( m_portRangeAddButton,     TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotPortRangeAddClicked( )));
+	connect( m_portRangeButton,        TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotPortRangeButtonClicked( )));
+	connect( m_portRangeDeleteButton,  TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotPortRangeDeleteClicked( )));
+	connect( m_portRangeComboBox,      TQ_SIGNAL( activated( int )),               TQ_SLOT( slotPortRangeActivated( int )));
+	connect( m_portRangeLineEdit,      TQ_SIGNAL( textChanged( const TQString& )),  TQ_SLOT( slotPortRangeTextChanged( const TQString& )));
+	connect( m_portRangeListBox,       TQ_SIGNAL( doubleClicked( TQListBoxItem* )), TQ_SLOT( slotPortRangeDoubleClicked( TQListBoxItem* )));
+	connect( m_portRangeListBox,       TQ_SIGNAL( highlighted( int )),             TQ_SLOT( slotPortRangeHighlighted( )));
+	connect( m_portRangesCheckBox,     TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotPortRangesClicked( )));
+	connect( whatsThis,                TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotWhatsThisClicked( )));
 
-	connect( m_hostButton,             SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_hostComboBox,           SIGNAL( activated ( int )),              SIGNAL( optionsDirty( )));
-	connect( m_hostComboBox,           SIGNAL( textChanged( const TQString& )),  SIGNAL( optionsDirty( )));
-	connect( m_portRangeAddButton,     SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_portRangeButton,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_portRangeComboBox,      SIGNAL( activated( int )),               SIGNAL( optionsDirty( )));
-	connect( m_portRangeDeleteButton,  SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_portRangeLineEdit,      SIGNAL( textChanged( const TQString& )),  SIGNAL( optionsDirty( )));
-	connect( m_portRangeListBox,       SIGNAL( doubleClicked( TQListBoxItem* )), SIGNAL( optionsDirty( )));
-	connect( m_portRangeListBox,       SIGNAL( highlighted ( int )),            SIGNAL( optionsDirty( )));
-	connect( m_portRangesCheckBox,     SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_resovleAlwaysRadio,     SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_resovleDefaultRadio,    SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_resovleNeverRadio,      SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
+	connect( m_hostButton,             TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_hostComboBox,           TQ_SIGNAL( activated ( int )),              TQ_SIGNAL( optionsDirty( )));
+	connect( m_hostComboBox,           TQ_SIGNAL( textChanged( const TQString& )),  TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeAddButton,     TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeButton,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeComboBox,      TQ_SIGNAL( activated( int )),               TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeDeleteButton,  TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeLineEdit,      TQ_SIGNAL( textChanged( const TQString& )),  TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeListBox,       TQ_SIGNAL( doubleClicked( TQListBoxItem* )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangeListBox,       TQ_SIGNAL( highlighted ( int )),            TQ_SIGNAL( optionsDirty( )));
+	connect( m_portRangesCheckBox,     TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_resovleAlwaysRadio,     TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_resovleDefaultRadio,    TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_resovleNeverRadio,      TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
 
 	emit( targetChanged( m_hostComboBox->currentText( )));
 }
@@ -282,7 +282,7 @@ bool CommonWidget::getOptions( )
 	bool portRangesState = m_portRangesCheckBox->isChecked( );
 
 	if( portRangesState && portRanges.isEmpty( ))
-	{	KMessageBox::error( this, i18n( TQString( "Port ranges not specified" )), i18n( "Port ranges error" ));
+	{	KMessageBox::error( this, i18n( "Port ranges not specified" ), i18n( "Port ranges error" ));
 		return false;
 	}
 
@@ -300,11 +300,11 @@ bool CommonWidget::getOptions( )
 	m_portRanges = new TQStringList( portRanges );
 	getHosts( m_hosts );
 
-	disconnect( m_hostComboBox, SIGNAL( activated( int )),              this, SLOT( slotHostActivated( int )));
-	disconnect( m_hostComboBox, SIGNAL( textChanged( const TQString& )), this, SLOT( slotHostTextChanged( const TQString& )));
+	disconnect( m_hostComboBox, TQ_SIGNAL( activated( int )),              this, TQ_SLOT( slotHostActivated( int )));
+	disconnect( m_hostComboBox, TQ_SIGNAL( textChanged( const TQString& )), this, TQ_SLOT( slotHostTextChanged( const TQString& )));
 
-	disconnect( m_hostComboBox, SIGNAL( activated ( int )),             this, SIGNAL( optionsDirty( )));
-	disconnect( m_hostComboBox, SIGNAL( textChanged( const TQString& )), this, SIGNAL( optionsDirty( )));
+	disconnect( m_hostComboBox, TQ_SIGNAL( activated ( int )),             this, TQ_SIGNAL( optionsDirty( )));
+	disconnect( m_hostComboBox, TQ_SIGNAL( textChanged( const TQString& )), this, TQ_SIGNAL( optionsDirty( )));
 
 	byte i;
 	TQStringList::Iterator it;
@@ -327,11 +327,11 @@ bool CommonWidget::getOptions( )
 	m_hostComboBox->setCurrentItem( 0 );
 	m_hosts->prepend( m_host );
 
-	connect( m_hostComboBox, SIGNAL( activated( int )),              SLOT( slotHostActivated( int )));
-	connect( m_hostComboBox, SIGNAL( textChanged( const TQString& )), SLOT( slotHostTextChanged( const TQString& )));
+	connect( m_hostComboBox, TQ_SIGNAL( activated( int )),              TQ_SLOT( slotHostActivated( int )));
+	connect( m_hostComboBox, TQ_SIGNAL( textChanged( const TQString& )), TQ_SLOT( slotHostTextChanged( const TQString& )));
 
-	connect( m_hostComboBox, SIGNAL( activated ( int )),             SIGNAL( optionsDirty( )));
-	connect( m_hostComboBox, SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
+	connect( m_hostComboBox, TQ_SIGNAL( activated ( int )),             TQ_SIGNAL( optionsDirty( )));
+	connect( m_hostComboBox, TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
 
 	return true;
 }
@@ -369,7 +369,7 @@ bool CommonWidget::portRangesOverlapping( const ushort portFirst, const ushort p
 
 		default:
 			kdDebug( ) << i18n( "unknown value in Port Range Protocol combo box" ) << endl;
-			ASSERT( false );
+			Q_ASSERT( false );
 			delete [] tcpPorts;
 			delete [] udpPorts;
 			return false;
@@ -495,7 +495,7 @@ void CommonWidget::slotPortRangeAddClicked( )
 
 		default:
 			kdDebug( ) << i18n( "unknown value in Port Range Protocol combo box" ) << endl;
-			ASSERT( false );
+			Q_ASSERT( false );
 	}
 
 	m_portRangeAddButton->setEnabled( false );
@@ -549,7 +549,7 @@ void CommonWidget::slotPortRangeDoubleClicked( TQListBoxItem* item )
 
 			default:
 				kdDebug( ) << i18n( "unknown value in Port Range Protocol" ) << endl;
-				ASSERT( false );
+				Q_ASSERT( false );
 				m_portRangeComboBox->setCurrentItem( BothProtocol ); 
 		}
 
@@ -653,3 +653,5 @@ bool CommonWidget::validatePortRangeText( TQString& text, uint& portFirst, uint&
 
 	return true;
 }
+
+#include "commonwidget.moc"
