@@ -190,61 +190,61 @@ void CompoundWidget::createLayout( )
 void CompoundWidget::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_dataDirButton,         SIGNAL( clicked( )), SLOT( slotDataDirButtonClicked( )));
-	connect( m_dataDirCheckBox,       SIGNAL( clicked( )), SLOT( slotDataDirCheckBoxClicked( )));
-	connect( m_dataLengthCheckBox,    SIGNAL( clicked( )), SLOT( slotDataLengthCheckBoxClicked( )));
-	connect( m_debugLevelCheckBox,    SIGNAL( clicked( )), SLOT( slotDebugLevelCheckBoxClicked( )));
-	connect( m_decoyButton,           SIGNAL( clicked( )), SLOT( slotDecoyButtonClicked( )));
-	connect( m_decoyCheckBox,         SIGNAL( clicked( )), SLOT( slotDecoyCheckBoxClicked( )));
-	connect( m_excludeButton,         SIGNAL( clicked( )), SLOT( slotExcludeButtonClicked( )));
-	connect( m_excludeCheckBox,       SIGNAL( clicked( )), SLOT( slotExcludeCheckBoxClicked( )));
-	connect( m_excludeFileButton,     SIGNAL( clicked( )), SLOT( slotExcludeFileButtonClicked( )));
-	connect( m_excludeFileCheckBox,   SIGNAL( clicked( )), SLOT( slotExcludeFileCheckBoxClicked( )));
-	connect( m_fragmentLevelCheckBox, SIGNAL( clicked( )), SLOT( slotFragmentLevelCheckBoxClicked( )));
-	connect( m_interfaceButton,       SIGNAL( clicked( )), SLOT( slotInterfaceButtonClicked( )));
-	connect( m_interfaceCheckBox,     SIGNAL( clicked( )), SLOT( slotInterfaceCheckBoxClicked( )));
-	connect( m_maxSocketsCheckBox,    SIGNAL( clicked( )), SLOT( slotMaxSocketsCheckBoxClicked( )));
-	connect( m_randomIPCheckBox,      SIGNAL( clicked( )), SLOT( slotRandomIPCheckBoxClicked( )));
-	connect( m_sourceIPButton,        SIGNAL( clicked( )), SLOT( slotSourceIPButtonClicked( )));
-	connect( m_sourceIPCheckBox,      SIGNAL( clicked( )), SLOT( slotSourceIPCheckBoxClicked( )));
-	connect( m_sourcePortCheckBox,    SIGNAL( clicked( )), SLOT( slotSourcePortCheckBoxClicked( )));
-	connect( m_spoofMacButton,        SIGNAL( clicked( )), SLOT( slotSpoofMACButtonClicked( )));
-	connect( m_spoofMacCheckBox,      SIGNAL( clicked( )), SLOT( slotSpoofMacCheckBoxClicked( )));
-	connect( m_targetFileButton,      SIGNAL( clicked( )), SLOT( slotTargetFileButtonClicked( )));
-	connect( m_targetFileCheckBox,    SIGNAL( clicked( )), SLOT( slotTargetFileCheckBoxClicked( )));
-	connect( m_ttlCheckBox,           SIGNAL( clicked( )), SLOT( slotTTLCheckBoxClicked( )));
-	connect( whatsThis,               SIGNAL( clicked( )), SLOT( slotWhatsThisClicked( )));
+	connect( m_dataDirButton,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotDataDirButtonClicked( )));
+	connect( m_dataDirCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotDataDirCheckBoxClicked( )));
+	connect( m_dataLengthCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotDataLengthCheckBoxClicked( )));
+	connect( m_debugLevelCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotDebugLevelCheckBoxClicked( )));
+	connect( m_decoyButton,           TQ_SIGNAL( clicked( )), TQ_SLOT( slotDecoyButtonClicked( )));
+	connect( m_decoyCheckBox,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotDecoyCheckBoxClicked( )));
+	connect( m_excludeButton,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotExcludeButtonClicked( )));
+	connect( m_excludeCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotExcludeCheckBoxClicked( )));
+	connect( m_excludeFileButton,     TQ_SIGNAL( clicked( )), TQ_SLOT( slotExcludeFileButtonClicked( )));
+	connect( m_excludeFileCheckBox,   TQ_SIGNAL( clicked( )), TQ_SLOT( slotExcludeFileCheckBoxClicked( )));
+	connect( m_fragmentLevelCheckBox, TQ_SIGNAL( clicked( )), TQ_SLOT( slotFragmentLevelCheckBoxClicked( )));
+	connect( m_interfaceButton,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotInterfaceButtonClicked( )));
+	connect( m_interfaceCheckBox,     TQ_SIGNAL( clicked( )), TQ_SLOT( slotInterfaceCheckBoxClicked( )));
+	connect( m_maxSocketsCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxSocketsCheckBoxClicked( )));
+	connect( m_randomIPCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotRandomIPCheckBoxClicked( )));
+	connect( m_sourceIPButton,        TQ_SIGNAL( clicked( )), TQ_SLOT( slotSourceIPButtonClicked( )));
+	connect( m_sourceIPCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotSourceIPCheckBoxClicked( )));
+	connect( m_sourcePortCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotSourcePortCheckBoxClicked( )));
+	connect( m_spoofMacButton,        TQ_SIGNAL( clicked( )), TQ_SLOT( slotSpoofMACButtonClicked( )));
+	connect( m_spoofMacCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotSpoofMacCheckBoxClicked( )));
+	connect( m_targetFileButton,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotTargetFileButtonClicked( )));
+	connect( m_targetFileCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotTargetFileCheckBoxClicked( )));
+	connect( m_ttlCheckBox,           TQ_SIGNAL( clicked( )), TQ_SLOT( slotTTLCheckBoxClicked( )));
+	connect( whatsThis,               TQ_SIGNAL( clicked( )), TQ_SLOT( slotWhatsThisClicked( )));
 
-	connect( m_dataDirCheckBox,       SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_dataDirLineEdit,       SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_dataLengthCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_dataLengthSpinBox,     SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_debugLevelCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_debugLevelSpinBox,     SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_decoyCheckBox,         SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_decoyLineEdit,         SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_excludeCheckBox,       SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_excludeLineEdit,       SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_excludeFileCheckBox,   SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_excludeFileLineEdit,   SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_fragmentLevelCheckBox, SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_fragmentLevelSpinBox,  SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_interfaceCheckBox,     SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_interfaceLineEdit,     SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_maxSocketsCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxSocketsSpinBox,     SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_randomIPCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_randomIPSpinBox,       SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_sourceIPCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_sourceIPLineEdit,      SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_sourcePortCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_sourcePortSpinBox,     SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
-	connect( m_spoofMacCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_spoofMacLineEdit,      SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_targetFileCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_targetFileLineEdit,    SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_ttlCheckBox,           SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_ttlSpinBox,            SIGNAL( valueChanged( int )),           SIGNAL( optionsDirty( )));
+	connect( m_dataDirCheckBox,       TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_dataDirLineEdit,       TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_dataLengthCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_dataLengthSpinBox,     TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_debugLevelCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_debugLevelSpinBox,     TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_decoyCheckBox,         TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_decoyLineEdit,         TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_excludeCheckBox,       TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_excludeLineEdit,       TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_excludeFileCheckBox,   TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_excludeFileLineEdit,   TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_fragmentLevelCheckBox, TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_fragmentLevelSpinBox,  TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_interfaceCheckBox,     TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_interfaceLineEdit,     TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxSocketsCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxSocketsSpinBox,     TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_randomIPCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_randomIPSpinBox,       TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_sourceIPCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_sourceIPLineEdit,      TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_sourcePortCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_sourcePortSpinBox,     TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
+	connect( m_spoofMacCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_spoofMacLineEdit,      TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_targetFileCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_targetFileLineEdit,    TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_ttlCheckBox,           TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_ttlSpinBox,            TQ_SIGNAL( valueChanged( int )),           TQ_SIGNAL( optionsDirty( )));
 }
 
 //	getOptions
