@@ -97,8 +97,8 @@ void HTMLWidget::loadLocalManPage( )
 	*m_process << "-w";
 	*m_process << "nmap";
 
-	connect( m_process, SIGNAL( processExited( TDEProcess* )), SLOT( slotManProcessExited( )));
-	connect( m_process, SIGNAL( receivedStdout( TDEProcess*, char*, int )), SLOT( slotManReceivedStdout( TDEProcess*, char*, int )));
+	connect( m_process, TQ_SIGNAL( processExited( TDEProcess* )), TQ_SLOT( slotManProcessExited( )));
+	connect( m_process, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int )), TQ_SLOT( slotManReceivedStdout( TDEProcess*, char*, int )));
 
 	m_manPagePath = TQString::null;
 	m_process->start( TDEProcess::NotifyOnExit, TDEProcess::Stdout );
@@ -155,7 +155,7 @@ void HTMLWidget::setInitialValues( )
 
 void HTMLWidget::setStylesheet( )
 {	m_dlg = new StylesheetDialog( m_stylesheetURL.path( ), *m_stylesheetURLs, this, "man stylesheet dlg" );
-	connect( m_dlg, SIGNAL( stylesheetRemoved( )), SLOT( slotStylesheetRemoved( )));
+	connect( m_dlg, TQ_SIGNAL( stylesheetRemoved( )), TQ_SLOT( slotStylesheetRemoved( )));
 
 	if( m_dlg->exec( ) != TQDialog::Accepted )
 	{	delete m_dlg;
@@ -189,8 +189,8 @@ void HTMLWidget::slotGunzipProcessExited( )
 	*m_process << "man2html";
 	*m_process << "-";
 
-	connect( m_process, SIGNAL( processExited( TDEProcess* )), SLOT( slotMan2HTMLProcessExited( )));
-	connect( m_process, SIGNAL( receivedStdout( TDEProcess*, char*, int )), SLOT( slotMan2HTMLReceivedStdout( TDEProcess*, char*, int )));
+	connect( m_process, TQ_SIGNAL( processExited( TDEProcess* )), TQ_SLOT( slotMan2HTMLProcessExited( )));
+	connect( m_process, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int )), TQ_SLOT( slotMan2HTMLReceivedStdout( TDEProcess*, char*, int )));
 
 	m_htmlData = TQString::null;
 	m_process->start( TDEProcess::NotifyOnExit, TDEProcess::Communication( TDEProcess::Stdin | TDEProcess::Stdout ));
@@ -284,8 +284,8 @@ void HTMLWidget::slotManProcessExited( )
 	*m_process << "-c";
 	*m_process << m_manPagePath;
 
-	connect( m_process, SIGNAL( processExited( TDEProcess* )), SLOT( slotGunzipProcessExited( )));
-	connect( m_process, SIGNAL( receivedStdout( TDEProcess*, char*, int )), SLOT( slotGunzipReceivedStdout( TDEProcess*, char*, int )));
+	connect( m_process, TQ_SIGNAL( processExited( TDEProcess* )), TQ_SLOT( slotGunzipProcessExited( )));
+	connect( m_process, TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int )), TQ_SLOT( slotGunzipReceivedStdout( TDEProcess*, char*, int )));
 
 	m_manPageData = TQString::null;
 	m_process->start( TDEProcess::NotifyOnExit, TDEProcess::Stdout );
@@ -311,11 +311,7 @@ void HTMLWidget::slotStylesheetRemoved( )
 
 bool HTMLWidget::tryKnmapFile( )
 {
-#ifdef _DEBUG
-	TQString path = "/home/c/knmap/src/nmap_manpage.html";
-#else
 	TQString path = locate( "data", "knmap/nmap_manpage.html" );
-#endif
 
 	if( !TQFile::exists( path ))
 		return false;
