@@ -85,15 +85,15 @@ void IndexWidget::contentsContextMenuEvent( TQContextMenuEvent* event )
 	TQIconSet     scanNew       = iconLoader->loadIconSet( "scannew",       TDEIcon::Small );
 	TQIconSet     scanRename    = iconLoader->loadIconSet( "scanrename",    TDEIcon::Small );
 
-	contextMenu->insertItem( scanClose,     i18n( "&Close scan"      ), parent( ), SLOT( slotScanClose( )),     CTRL+Key_W );
-	contextMenu->insertItem( scanDuplicate, i18n( "&Duplicate scan"  ), parent( ), SLOT( slotScanDuplicate( )), CTRL+Key_C );
-	contextMenu->insertItem( scanNew,       i18n( "&New scan..."     ), parent( ), SLOT( slotScanNew( )),       CTRL+Key_N );
-	contextMenu->insertItem( scanRename,    i18n( "&Rename scan..."  ), parent( ), SLOT( slotScanRename( )),    Key_F2     );
-	contextMenu->insertItem( i18n( "&Use target host name" ), parent( ), SLOT( slotUseTargetHost( )));
+	contextMenu->insertItem( scanClose,     i18n( "&Close scan"      ), parent( ), TQ_SLOT( slotScanClose( )),     CTRL+Key_W );
+	contextMenu->insertItem( scanDuplicate, i18n( "&Duplicate scan"  ), parent( ), TQ_SLOT( slotScanDuplicate( )), CTRL+Key_C );
+	contextMenu->insertItem( scanNew,       i18n( "&New scan..."     ), parent( ), TQ_SLOT( slotScanNew( )),       CTRL+Key_N );
+	contextMenu->insertItem( scanRename,    i18n( "&Rename scan..."  ), parent( ), TQ_SLOT( slotScanRename( )),    Key_F2     );
+	contextMenu->insertItem( i18n( "&Use target host name" ), parent( ), TQ_SLOT( slotUseTargetHost( )));
 	contextMenu->insertSeparator( );
-	contextMenu->insertItem( profileLoad,   i18n( "&Load profile..."    ), parent( ), SLOT( slotProfileLoad( )));
-	contextMenu->insertItem( profileSave,   i18n( "&Save profile..."    ), parent( ), SLOT( slotProfileSave( )));
-	contextMenu->insertItem( profileSaveAs, i18n( "&Save profile as..." ), parent( ), SLOT( slotProfileSaveAs( )));
+	contextMenu->insertItem( profileLoad,   i18n( "&Load profile..."    ), parent( ), TQ_SLOT( slotProfileLoad( )));
+	contextMenu->insertItem( profileSave,   i18n( "&Save profile..."    ), parent( ), TQ_SLOT( slotProfileSave( )));
+	contextMenu->insertItem( profileSaveAs, i18n( "&Save profile as..." ), parent( ), TQ_SLOT( slotProfileSaveAs( )));
 
 	contextMenu->exec( event->globalPos( ));
 }
@@ -253,7 +253,7 @@ void IndexWidget::slotScanStarted( )
 
 	Q_ASSERT( m_blinkTimer == NULL );
 	m_blinkTimer = new TQTimer( this );
-	connect( m_blinkTimer, SIGNAL( timeout( )), SLOT( slotRepaint( )));
+	connect( m_blinkTimer, TQ_SIGNAL( timeout( )), TQ_SLOT( slotRepaint( )));
 	m_blinkTimer->start( 500 );
 	m_highlight = true;
 }
