@@ -130,38 +130,38 @@ void LoggingOptions::createLayout( )
 void LoggingOptions::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_baseFileNameButton,   SIGNAL( clicked( )), SLOT( slotBaseFileNameButtonClicked( )));
-	connect( m_baseFileNameCheckBox, SIGNAL( clicked( )), SLOT( slotBaseFileNameCheckBoxClicked( )));
-	connect( m_grepableLogButton,    SIGNAL( clicked( )), SLOT( slotGrepableLogButtonClicked( )));
-	connect( m_grepableLogCheckBox,  SIGNAL( clicked( )), SLOT( slotGrepableLogCheckBoxClicked( )));
-	connect( m_normalLogButton,      SIGNAL( clicked( )), SLOT( slotNormalLogButtonClicked( )));
-	connect( m_normalLogCheckBox,    SIGNAL( clicked( )), SLOT( slotNormalLogCheckBoxClicked( )));
-	connect( m_noStylesheetCheckBox, SIGNAL( clicked( )), SLOT( slotNoStylesheetCheckBoxClicked( )));
-	connect( m_resumeButton,         SIGNAL( clicked( )), SLOT( slotResumeButtonClicked( )));
-	connect( m_resumeCheckBox,       SIGNAL( clicked( )), SLOT( slotResumeCheckBoxClicked( )));
-	connect( m_scriptKiddieButton,   SIGNAL( clicked( )), SLOT( slotScriptKiddieButtonClicked( )));
-	connect( m_scriptKiddieCheckBox, SIGNAL( clicked( )), SLOT( slotScriptKiddieCheckBoxClicked( )));
-	connect( m_stylesheetButton,     SIGNAL( clicked( )), SLOT( slotStylesheetButtonClicked( )));
-	connect( m_stylesheetCheckBox,   SIGNAL( clicked( )), SLOT( slotStylesheetCheckBoxClicked( )));
-	connect( whatsThis,              SIGNAL( clicked( )), SLOT( slotWhatsThisClicked( )));
-	connect( m_xmlLogButton,         SIGNAL( clicked( )), SLOT( slotXMLLogButtonClicked( )));
-	connect( m_xmlLogCheckBox,       SIGNAL( clicked( )), SLOT( slotXMLLogCheckBoxClicked( )));
+	connect( m_baseFileNameButton,   TQ_SIGNAL( clicked( )), TQ_SLOT( slotBaseFileNameButtonClicked( )));
+	connect( m_baseFileNameCheckBox, TQ_SIGNAL( clicked( )), TQ_SLOT( slotBaseFileNameCheckBoxClicked( )));
+	connect( m_grepableLogButton,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotGrepableLogButtonClicked( )));
+	connect( m_grepableLogCheckBox,  TQ_SIGNAL( clicked( )), TQ_SLOT( slotGrepableLogCheckBoxClicked( )));
+	connect( m_normalLogButton,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotNormalLogButtonClicked( )));
+	connect( m_normalLogCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotNormalLogCheckBoxClicked( )));
+	connect( m_noStylesheetCheckBox, TQ_SIGNAL( clicked( )), TQ_SLOT( slotNoStylesheetCheckBoxClicked( )));
+	connect( m_resumeButton,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotResumeButtonClicked( )));
+	connect( m_resumeCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotResumeCheckBoxClicked( )));
+	connect( m_scriptKiddieButton,   TQ_SIGNAL( clicked( )), TQ_SLOT( slotScriptKiddieButtonClicked( )));
+	connect( m_scriptKiddieCheckBox, TQ_SIGNAL( clicked( )), TQ_SLOT( slotScriptKiddieCheckBoxClicked( )));
+	connect( m_stylesheetButton,     TQ_SIGNAL( clicked( )), TQ_SLOT( slotStylesheetButtonClicked( )));
+	connect( m_stylesheetCheckBox,   TQ_SIGNAL( clicked( )), TQ_SLOT( slotStylesheetCheckBoxClicked( )));
+	connect( whatsThis,              TQ_SIGNAL( clicked( )), TQ_SLOT( slotWhatsThisClicked( )));
+	connect( m_xmlLogButton,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotXMLLogButtonClicked( )));
+	connect( m_xmlLogCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotXMLLogCheckBoxClicked( )));
 
-	connect( m_appendOutputCheckBox, SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_baseFileNameCheckBox, SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_baseFileNameLineEdit, SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_grepableLogCheckBox,  SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_grepableLogLineEdit,  SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_normalLogCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_normalLogLineEdit,    SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_resumeCheckBox,       SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_resumeLineEdit,       SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_scriptKiddieCheckBox, SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_scriptKiddieLineEdit, SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_stylesheetCheckBox,   SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_stylesheetLineEdit,   SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_xmlLogCheckBox,       SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_xmlLogLineEdit,       SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
+	connect( m_appendOutputCheckBox, TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_baseFileNameCheckBox, TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_baseFileNameLineEdit, TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_grepableLogCheckBox,  TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_grepableLogLineEdit,  TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_normalLogCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_normalLogLineEdit,    TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_resumeCheckBox,       TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_resumeLineEdit,       TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_scriptKiddieCheckBox, TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_scriptKiddieLineEdit, TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_stylesheetCheckBox,   TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_stylesheetLineEdit,   TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_xmlLogCheckBox,       TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_xmlLogLineEdit,       TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
 }
 
 //	getOptions
