@@ -51,15 +51,15 @@ MainWidget::MainWidget( TQWidget* parent, const char* name )
 	moveToFirst( m_indexWidget );
 	m_scanStack->appendHTMLWidget( m_htmlWidget );
 	setOpaqueResize( true );
-	TQTimer::singleShot( 0, this, SLOT( slotFinaliseInitialisation( )));
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotFinaliseInitialisation( )));
 
 	connect( m_htmlWidget,
-			 SIGNAL( errorLoadingLocalManPage( const TQString& )),
-			 SLOT( slotErrorLoadingLocalManPage( const TQString& )));
+			 TQ_SIGNAL( errorLoadingLocalManPage( const TQString& )),
+			 TQ_SLOT( slotErrorLoadingLocalManPage( const TQString& )));
 
 	connect( m_indexWidget,
-			 SIGNAL( visibleScanWidgetChanged( ScanWidget* )),
-			 SLOT( slotVisibleScanWidgetChanged( ScanWidget* )));
+			 TQ_SIGNAL( visibleScanWidgetChanged( ScanWidget* )),
+			 TQ_SLOT( slotVisibleScanWidgetChanged( ScanWidget* )));
 }
 
 //	createScan
@@ -77,34 +77,34 @@ ScanWidget* MainWidget::createScan( const TQString& scanName, const bool useTarg
 		scanWidget->setProfileName( profileName );
 
 	connect( scanWidget,
-			 SIGNAL( displayHelp( const TQString& )),
-			 SLOT( slotDisplayHelp( const TQString& )));
+			 TQ_SIGNAL( displayHelp( const TQString& )),
+			 TQ_SLOT( slotDisplayHelp( const TQString& )));
 
 	connect( scanWidget,
-			 SIGNAL( optionsDirty( )),
-			 SLOT( slotOptionsDirty( )));
+			 TQ_SIGNAL( optionsDirty( )),
+			 TQ_SLOT( slotOptionsDirty( )));
 
 	connect( scanWidget,
-			 SIGNAL( outputAvailable( const bool, const bool )),
-			 SIGNAL( outputAvailable( const bool, const bool )));
+			 TQ_SIGNAL( outputAvailable( const bool, const bool )),
+			 TQ_SIGNAL( outputAvailable( const bool, const bool )));
 
 	connect( scanWidget,
-			 SIGNAL( scanRename( const TQString& )),
-			 SLOT( slotScanRename( const TQString& )));
+			 TQ_SIGNAL( scanRename( const TQString& )),
+			 TQ_SLOT( slotScanRename( const TQString& )));
 
 	connect( scanWidget,
-			 SIGNAL( scanStarted( )),
+			 TQ_SIGNAL( scanStarted( )),
 			 m_indexWidget,
-			 SLOT( slotScanStarted( )));
+			 TQ_SLOT( slotScanStarted( )));
 
 	connect( scanWidget,
-			 SIGNAL( scanStopped( ScanWidget* )),
+			 TQ_SIGNAL( scanStopped( ScanWidget* )),
 			 m_indexWidget,
-			 SLOT( slotScanStopped( ScanWidget* )));
+			 TQ_SLOT( slotScanStopped( ScanWidget* )));
 
 	connect( scanWidget,
-			 SIGNAL( statusBarText( const TQString& )),
-			 SIGNAL( statusBarText( const TQString& )));
+			 TQ_SIGNAL( statusBarText( const TQString& )),
+			 TQ_SIGNAL( statusBarText( const TQString& )));
 
 	return scanWidget;
 }
