@@ -42,7 +42,7 @@ OutputWidget::OutputWidget( TQWidget* parent, const char* name )
   m_priorType( OutputType( -1 ))
 {	setFamily( "monospace" );
 	setReadOnly( true );
-	TQTimer::singleShot( 0, this, SLOT( slotUpdateStatusBarText( )));
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotUpdateStatusBarText( )));
 }
 
 //	addOutput
