@@ -170,38 +170,38 @@ void PAndSOptions::createLayout( )
 void PAndSOptions::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_ackCheckBox,            SIGNAL( clicked( )), SLOT( slotAckClicked( )));
-	connect( m_scanFTPBounceCheckBox,  SIGNAL( clicked( )), SLOT( slotScanFTPBounceCheckBoxClicked( )));
-	connect( m_scanIdleCheckBox,       SIGNAL( clicked( )), SLOT( slotScanIdleCheckBoxClicked( )));
-	connect( m_synCheckBox,            SIGNAL( clicked( )), SLOT( slotSynClicked( )));
-	connect( whatsThis,                SIGNAL( clicked( )), SLOT( slotWhatsThisClicked( )));
+	connect( m_ackCheckBox,            TQ_SIGNAL( clicked( )), TQ_SLOT( slotAckClicked( )));
+	connect( m_scanFTPBounceCheckBox,  TQ_SIGNAL( clicked( )), TQ_SLOT( slotScanFTPBounceCheckBoxClicked( )));
+	connect( m_scanIdleCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotScanIdleCheckBoxClicked( )));
+	connect( m_synCheckBox,            TQ_SIGNAL( clicked( )), TQ_SLOT( slotSynClicked( )));
+	connect( whatsThis,                TQ_SIGNAL( clicked( )), TQ_SLOT( slotWhatsThisClicked( )));
 
-	connect( m_ackCheckBox,            SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_ackLineEdit,            SIGNAL( textChanged ( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_arpCheckBox,            SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_dontPingCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_echoCheckBox,           SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_netmaskCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanAckCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanFINCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanFTPBounceCheckBox,  SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanFTPRelayLineEdit,   SIGNAL( textChanged ( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_scanIdleCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanListCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanNullCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanPingCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanProtocolCheckBox,   SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanRPCCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanSYNCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanTCPConnectCheckBox, SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanUDPCheckBox,        SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanVersionCheckBox,    SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanWindowCheckBox,     SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_scanXmasCheckBox,       SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_synCheckBox,            SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_synLineEdit,            SIGNAL( textChanged ( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_timestampCheckBox,      SIGNAL( clicked( )),                     SIGNAL( optionsDirty( )));
-	connect( m_zombieLineEdit,         SIGNAL( textChanged ( const TQString& )), SIGNAL( optionsDirty( )));
+	connect( m_ackCheckBox,            TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_ackLineEdit,            TQ_SIGNAL( textChanged ( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_arpCheckBox,            TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_dontPingCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_echoCheckBox,           TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_netmaskCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanAckCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanFINCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanFTPBounceCheckBox,  TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanFTPRelayLineEdit,   TQ_SIGNAL( textChanged ( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanIdleCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanListCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanNullCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanPingCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanProtocolCheckBox,   TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanRPCCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanSYNCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanTCPConnectCheckBox, TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanUDPCheckBox,        TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanVersionCheckBox,    TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanWindowCheckBox,     TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanXmasCheckBox,       TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_synCheckBox,            TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_synLineEdit,            TQ_SIGNAL( textChanged ( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_timestampCheckBox,      TQ_SIGNAL( clicked( )),                     TQ_SIGNAL( optionsDirty( )));
+	connect( m_zombieLineEdit,         TQ_SIGNAL( textChanged ( const TQString& )), TQ_SIGNAL( optionsDirty( )));
 }
 
 //	getOptions
