@@ -86,7 +86,7 @@ ScanWidget::ScanWidget( const TQString& scanName,
 	m_startButton->setDefault( true );
 
 	srand( time( NULL ));
-	TQTimer::singleShot( 0, this, SLOT( slotFinaliseInitialisation( )));
+	TQTimer::singleShot( 0, this, TQ_SLOT( slotFinaliseInitialisation( )));
 }
 
 //	destructor
@@ -836,45 +836,45 @@ void ScanWidget::slotFinaliseInitialisation( )
 	m_simpleWidget->finaliseInitialisation( );
 	m_timingWidget->finaliseInitialisation( );
 
-	connect( m_outputWidget,      SIGNAL( statusBarText( const TQString& )),       SIGNAL( statusBarText( const TQString& )));
+	connect( m_outputWidget,      TQ_SIGNAL( statusBarText( const TQString& )),       TQ_SIGNAL( statusBarText( const TQString& )));
 
-	connect( m_clearOutputButton, SIGNAL( clicked( )),                            SLOT( slotClearOutput( )));
-	connect( m_commonWidget,      SIGNAL( disableFastScan( )),    m_simpleWidget, SLOT( slotDisableFastScan( )));
-	connect( m_commonWidget,      SIGNAL( targetChanged( const TQString& )),       SLOT( slotTargetChanged( const TQString& )));
-	connect( m_hideOptionsButton, SIGNAL( clicked( )),                            SLOT( slotHideOptions( )));
-	connect( m_simpleWidget,      SIGNAL( disablePortRanges( )),  m_commonWidget, SLOT( slotDisablePortRanges( )));
-	connect( m_startButton,       SIGNAL( clicked( )),                            SLOT( slotStartClicked( )));
-	connect( m_stopButton,        SIGNAL( clicked( )),                            SLOT( slotStopClicked( )));
-	connect( m_tabWidget,         SIGNAL( currentChanged( TQWidget* )),            SLOT( slotTabChanged( TQWidget* )));
+	connect( m_clearOutputButton, TQ_SIGNAL( clicked( )),                            TQ_SLOT( slotClearOutput( )));
+	connect( m_commonWidget,      TQ_SIGNAL( disableFastScan( )),    m_simpleWidget, TQ_SLOT( slotDisableFastScan( )));
+	connect( m_commonWidget,      TQ_SIGNAL( targetChanged( const TQString& )),       TQ_SLOT( slotTargetChanged( const TQString& )));
+	connect( m_hideOptionsButton, TQ_SIGNAL( clicked( )),                            TQ_SLOT( slotHideOptions( )));
+	connect( m_simpleWidget,      TQ_SIGNAL( disablePortRanges( )),  m_commonWidget, TQ_SLOT( slotDisablePortRanges( )));
+	connect( m_startButton,       TQ_SIGNAL( clicked( )),                            TQ_SLOT( slotStartClicked( )));
+	connect( m_stopButton,        TQ_SIGNAL( clicked( )),                            TQ_SLOT( slotStopClicked( )));
+	connect( m_tabWidget,         TQ_SIGNAL( currentChanged( TQWidget* )),            TQ_SLOT( slotTabChanged( TQWidget* )));
 
-	connect( m_commonWidget,      SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
-	connect( m_compoundWidget,    SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
-	connect( m_loggingWidget,     SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
-	connect( m_pAndSWidget,       SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
-	connect( m_simpleWidget,      SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
-	connect( m_tabWidget,         SIGNAL( movedTab( int, int )),                  SLOT( slotOptionsDirty( )));
-	connect( m_timingWidget,      SIGNAL( optionsDirty( )),                       SLOT( slotOptionsDirty( )));
+	connect( m_commonWidget,      TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
+	connect( m_compoundWidget,    TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
+	connect( m_loggingWidget,     TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
+	connect( m_pAndSWidget,       TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
+	connect( m_simpleWidget,      TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
+	connect( m_tabWidget,         TQ_SIGNAL( movedTab( int, int )),                  TQ_SLOT( slotOptionsDirty( )));
+	connect( m_timingWidget,      TQ_SIGNAL( optionsDirty( )),                       TQ_SLOT( slotOptionsDirty( )));
 
-	connect( m_commonWidget,      SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
-	connect( m_compoundWidget,    SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
-	connect( m_loggingWidget,     SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
-	connect( m_pAndSWidget,       SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
-	connect( m_simpleWidget,      SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
-	connect( m_timingWidget,      SIGNAL( displayHelp( const TQString& )),         SIGNAL( displayHelp( const TQString& )));
+	connect( m_commonWidget,      TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
+	connect( m_compoundWidget,    TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
+	connect( m_loggingWidget,     TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
+	connect( m_pAndSWidget,       TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
+	connect( m_simpleWidget,      TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
+	connect( m_timingWidget,      TQ_SIGNAL( displayHelp( const TQString& )),         TQ_SIGNAL( displayHelp( const TQString& )));
 
-	connect( m_commonWidget,      SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
-	connect( m_compoundWidget,    SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
-	connect( m_loggingWidget,     SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
-	connect( m_pAndSWidget,       SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
-	connect( m_simpleWidget,      SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
-	connect( m_timingWidget,      SIGNAL( displayDocBook( const TQString& )),      SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_commonWidget,      TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_compoundWidget,    TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_loggingWidget,     TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_pAndSWidget,       TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_simpleWidget,      TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
+	connect( m_timingWidget,      TQ_SIGNAL( displayDocBook( const TQString& )),      TQ_SLOT( slotDisplayDocBook( const TQString&)));
 
-	connect( m_commonWidget,      SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
-	connect( m_compoundWidget,    SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
-	connect( m_loggingWidget,     SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
-	connect( m_pAndSWidget,       SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
-	connect( m_simpleWidget,      SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
-	connect( m_timingWidget,      SIGNAL( displayUnknown( )),                     SLOT( slotDisplayUnknown( )));
+	connect( m_commonWidget,      TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
+	connect( m_compoundWidget,    TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
+	connect( m_loggingWidget,     TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
+	connect( m_pAndSWidget,       TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
+	connect( m_simpleWidget,      TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
+	connect( m_timingWidget,      TQ_SIGNAL( displayUnknown( )),                     TQ_SLOT( slotDisplayUnknown( )));
 
 	if( m_useTargetHost )
 		renameScan( m_commonWidget->getHostName( ));
@@ -986,16 +986,16 @@ void ScanWidget::slotStartClicked( )
 	m_outputWidget->addOutput( OutputWidget::Stdin, cmd.local8Bit(), cmd.local8Bit().length( ));
 
 	emit( outputAvailable( true, true ));
-	connect( m_nmapProcess, SIGNAL( processExited( TDEProcess* )), SLOT( slotProcessExited( )));
+	connect( m_nmapProcess, TQ_SIGNAL( processExited( TDEProcess* )), TQ_SLOT( slotProcessExited( )));
 
 	if( !m_piping )
 	{	connect( m_nmapProcess,
-				 SIGNAL( receivedStderr( TDEProcess*, char*, int )),
-				 SLOT( slotReceivedStderr( TDEProcess*, char*, int )));
+				 TQ_SIGNAL( receivedStderr( TDEProcess*, char*, int )),
+				 TQ_SLOT( slotReceivedStderr( TDEProcess*, char*, int )));
 
 		connect( m_nmapProcess,
-				 SIGNAL( receivedStdout( TDEProcess*, char*, int )),
-				 SLOT( slotReceivedStdout( TDEProcess*, char*, int )));
+				 TQ_SIGNAL( receivedStdout( TDEProcess*, char*, int )),
+				 TQ_SLOT( slotReceivedStdout( TDEProcess*, char*, int )));
 	}
 
 	m_nmapProcess->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
