@@ -114,22 +114,22 @@ void SimpleOptions::createLayout( )
 void SimpleOptions::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_fastScanCheckBox,       SIGNAL( clicked( )), SLOT( slotFastScanCheckBoxClicked( )));
-	connect( whatsThis,                SIGNAL( clicked( )), SLOT( slotWhatsThisClicked( )));
+	connect( m_fastScanCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotFastScanCheckBoxClicked( )));
+	connect( whatsThis,                TQ_SIGNAL( clicked( )), TQ_SLOT( slotWhatsThisClicked( )));
 
-	connect( m_allPortsCheckBox,       SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_fastScanCheckBox,       SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_ipV6CheckBox,           SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_noRandomPortsCheckBox,  SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_osDetectionCheckBox,    SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_osScanLimitCheckBox,    SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_packetTraceCheckBox,    SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_prepackagedCheckBox,    SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_privilegedCheckBox,     SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_randomizeHostsCheckBox, SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_sendEthCheckBox,        SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_sendIPCheckBox,         SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
-	connect( m_verboseCheckBox,        SIGNAL( clicked( )), SIGNAL( optionsDirty( )));
+	connect( m_allPortsCheckBox,       TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_fastScanCheckBox,       TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_ipV6CheckBox,           TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_noRandomPortsCheckBox,  TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_osDetectionCheckBox,    TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_osScanLimitCheckBox,    TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_packetTraceCheckBox,    TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_prepackagedCheckBox,    TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_privilegedCheckBox,     TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_randomizeHostsCheckBox, TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_sendEthCheckBox,        TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_sendIPCheckBox,         TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_verboseCheckBox,        TQ_SIGNAL( clicked( )), TQ_SIGNAL( optionsDirty( )));
 }
 
 //	getOptions
