@@ -74,8 +74,8 @@ StylesheetDialog::StylesheetDialog( const TQString&     currentStylesheetURL,
 	layout->setRowStretch( 3, 10 );
 	layout->setRowStretch( 4,  2 );
 
-	connect( urlButton,    SIGNAL( clicked( )),                     SLOT( slotURLButtonClicked( )));
-	connect( m_urlListBox, SIGNAL( doubleClicked( TQListBoxItem* )), SLOT( slotURLListBoxDoubleClicked( TQListBoxItem* )));
+	connect( urlButton,    TQ_SIGNAL( clicked( )),                     TQ_SLOT( slotURLButtonClicked( )));
+	connect( m_urlListBox, TQ_SIGNAL( doubleClicked( TQListBoxItem* )), TQ_SLOT( slotURLListBoxDoubleClicked( TQListBoxItem* )));
 }
 
 //	slotOk
