@@ -173,62 +173,62 @@ void TimingWidget::createLayout( )
 void TimingWidget::finaliseInitialisation( )
 {	WhatsThis* whatsThis = new WhatsThis( this );
 
-	connect( m_aggressiveRadio,           SIGNAL( clicked( )), SLOT( slotAggressiveRadioClicked( )));
-	connect( m_defaultRadio,              SIGNAL( clicked( )), SLOT( slotDefaultRadioClicked( )));
-	connect( m_hostTimeoutButton,         SIGNAL( clicked( )), SLOT( slotHostTimeoutButtonClicked( )));
-	connect( m_hostTimeoutCheckBox,       SIGNAL( clicked( )), SLOT( slotHostTimeoutCheckBoxClicked( )));
-	connect( m_initialRTTTimeoutButton,   SIGNAL( clicked( )), SLOT( slotInitialRTTTimeoutButtonClicked( )));
-	connect( m_initialRTTTimeoutCheckBox, SIGNAL( clicked( )), SLOT( slotInitialRTTTimeoutCheckBoxClicked( )));
-	connect( m_insaneRadio,               SIGNAL( clicked( )), SLOT( slotInsaneRadioClicked( )));
-	connect( m_maxHostGroupButton,        SIGNAL( clicked( )), SLOT( slotMaxHostGroupButtonClicked( )));
-	connect( m_maxHostGroupCheckBox,      SIGNAL( clicked( )), SLOT( slotMaxHostGroupCheckBoxClicked( )));
-	connect( m_maxParallelismButton,      SIGNAL( clicked( )), SLOT( slotMaxParallelismButtonClicked( )));
-	connect( m_maxParallelismCheckBox,    SIGNAL( clicked( )), SLOT( slotMaxParallelismCheckBoxClicked( )));
-	connect( m_maxRTTTimeoutButton,       SIGNAL( clicked( )), SLOT( slotMaxRTTTimeoutButtonClicked( )));
-	connect( m_maxRTTTimeoutCheckBox,     SIGNAL( clicked( )), SLOT( slotMaxRTTTimeoutCheckBoxClicked( )));
-	connect( m_maxScanDelayButton,        SIGNAL( clicked( )), SLOT( slotMaxScanDelayButtonClicked( )));
-	connect( m_maxScanDelayCheckBox,      SIGNAL( clicked( )), SLOT( slotMaxScanDelayCheckBoxClicked( )));
-	connect( m_minHostGroupButton,        SIGNAL( clicked( )), SLOT( slotMinHostGroupButtonClicked( )));
-	connect( m_minHostGroupCheckBox,      SIGNAL( clicked( )), SLOT( slotMinHostGroupCheckBoxClicked( )));
-	connect( m_minParallelismButton,      SIGNAL( clicked( )), SLOT( slotMinParallelismButtonClicked( )));
-	connect( m_minParallelismCheckBox,    SIGNAL( clicked( )), SLOT( slotMinParallelismCheckBoxClicked( )));
-	connect( m_minRTTTimeoutButton,       SIGNAL( clicked( )), SLOT( slotMinRTTTimeoutButtonClicked( )));
-	connect( m_minRTTTimeoutCheckBox,     SIGNAL( clicked( )), SLOT( slotMinRTTTimeoutCheckBoxClicked( )));
-	connect( m_normalRadio,               SIGNAL( clicked( )), SLOT( slotNormalRadioClicked( )));
-	connect( m_paranoidRadio,             SIGNAL( clicked( )), SLOT( slotParanoidRadioClicked( )));
-	connect( m_politeRadio,               SIGNAL( clicked( )), SLOT( slotPoliteRadioClicked( )));
-	connect( m_scanDelayButton,           SIGNAL( clicked( )), SLOT( slotScanDelayButtonClicked( )));
-	connect( m_scanDelayCheckBox,         SIGNAL( clicked( )), SLOT( slotScanDelayCheckBoxClicked( )));
-	connect( m_sneakyRadio,               SIGNAL( clicked( )), SLOT( slotSneakyRadioClicked( )));
-	connect( whatsThis,                   SIGNAL( clicked( )), SLOT( slotWhatsThisClicked( )));
+	connect( m_aggressiveRadio,           TQ_SIGNAL( clicked( )), TQ_SLOT( slotAggressiveRadioClicked( )));
+	connect( m_defaultRadio,              TQ_SIGNAL( clicked( )), TQ_SLOT( slotDefaultRadioClicked( )));
+	connect( m_hostTimeoutButton,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotHostTimeoutButtonClicked( )));
+	connect( m_hostTimeoutCheckBox,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotHostTimeoutCheckBoxClicked( )));
+	connect( m_initialRTTTimeoutButton,   TQ_SIGNAL( clicked( )), TQ_SLOT( slotInitialRTTTimeoutButtonClicked( )));
+	connect( m_initialRTTTimeoutCheckBox, TQ_SIGNAL( clicked( )), TQ_SLOT( slotInitialRTTTimeoutCheckBoxClicked( )));
+	connect( m_insaneRadio,               TQ_SIGNAL( clicked( )), TQ_SLOT( slotInsaneRadioClicked( )));
+	connect( m_maxHostGroupButton,        TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxHostGroupButtonClicked( )));
+	connect( m_maxHostGroupCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxHostGroupCheckBoxClicked( )));
+	connect( m_maxParallelismButton,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxParallelismButtonClicked( )));
+	connect( m_maxParallelismCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxParallelismCheckBoxClicked( )));
+	connect( m_maxRTTTimeoutButton,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxRTTTimeoutButtonClicked( )));
+	connect( m_maxRTTTimeoutCheckBox,     TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxRTTTimeoutCheckBoxClicked( )));
+	connect( m_maxScanDelayButton,        TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxScanDelayButtonClicked( )));
+	connect( m_maxScanDelayCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotMaxScanDelayCheckBoxClicked( )));
+	connect( m_minHostGroupButton,        TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinHostGroupButtonClicked( )));
+	connect( m_minHostGroupCheckBox,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinHostGroupCheckBoxClicked( )));
+	connect( m_minParallelismButton,      TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinParallelismButtonClicked( )));
+	connect( m_minParallelismCheckBox,    TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinParallelismCheckBoxClicked( )));
+	connect( m_minRTTTimeoutButton,       TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinRTTTimeoutButtonClicked( )));
+	connect( m_minRTTTimeoutCheckBox,     TQ_SIGNAL( clicked( )), TQ_SLOT( slotMinRTTTimeoutCheckBoxClicked( )));
+	connect( m_normalRadio,               TQ_SIGNAL( clicked( )), TQ_SLOT( slotNormalRadioClicked( )));
+	connect( m_paranoidRadio,             TQ_SIGNAL( clicked( )), TQ_SLOT( slotParanoidRadioClicked( )));
+	connect( m_politeRadio,               TQ_SIGNAL( clicked( )), TQ_SLOT( slotPoliteRadioClicked( )));
+	connect( m_scanDelayButton,           TQ_SIGNAL( clicked( )), TQ_SLOT( slotScanDelayButtonClicked( )));
+	connect( m_scanDelayCheckBox,         TQ_SIGNAL( clicked( )), TQ_SLOT( slotScanDelayCheckBoxClicked( )));
+	connect( m_sneakyRadio,               TQ_SIGNAL( clicked( )), TQ_SLOT( slotSneakyRadioClicked( )));
+	connect( whatsThis,                   TQ_SIGNAL( clicked( )), TQ_SLOT( slotWhatsThisClicked( )));
 
-	connect( m_aggressiveRadio,           SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_defaultRadio,              SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_hostTimeoutCheckBox,       SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_hostTimeoutLineEdit,       SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_initialRTTTimeoutCheckBox, SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_initialRTTTimeoutLineEdit, SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_insaneRadio,               SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxHostGroupCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxHostGroupLineEdit,      SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_maxParallelismCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxParallelismLineEdit,    SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_maxRTTTimeoutCheckBox,     SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxRTTTimeoutLineEdit,     SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_maxScanDelayCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_maxScanDelayLineEdit,      SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_minHostGroupCheckBox,      SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_minHostGroupLineEdit,      SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_minParallelismCheckBox,    SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_minParallelismLineEdit,    SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_minRTTTimeoutCheckBox,     SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_minRTTTimeoutLineEdit,     SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_normalRadio,               SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_paranoidRadio,             SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_politeRadio,               SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_scanDelayCheckBox,         SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
-	connect( m_scanDelayLineEdit,         SIGNAL( textChanged( const TQString& )), SIGNAL( optionsDirty( )));
-	connect( m_sneakyRadio,               SIGNAL( clicked( )),                    SIGNAL( optionsDirty( )));
+	connect( m_aggressiveRadio,           TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_defaultRadio,              TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_hostTimeoutCheckBox,       TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_hostTimeoutLineEdit,       TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_initialRTTTimeoutCheckBox, TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_initialRTTTimeoutLineEdit, TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_insaneRadio,               TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxHostGroupCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxHostGroupLineEdit,      TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxParallelismCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxParallelismLineEdit,    TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxRTTTimeoutCheckBox,     TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxRTTTimeoutLineEdit,     TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxScanDelayCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_maxScanDelayLineEdit,      TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_minHostGroupCheckBox,      TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_minHostGroupLineEdit,      TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_minParallelismCheckBox,    TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_minParallelismLineEdit,    TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_minRTTTimeoutCheckBox,     TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_minRTTTimeoutLineEdit,     TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_normalRadio,               TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_paranoidRadio,             TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_politeRadio,               TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanDelayCheckBox,         TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
+	connect( m_scanDelayLineEdit,         TQ_SIGNAL( textChanged( const TQString& )), TQ_SIGNAL( optionsDirty( )));
+	connect( m_sneakyRadio,               TQ_SIGNAL( clicked( )),                    TQ_SIGNAL( optionsDirty( )));
 }
 
 //	getOptions
